# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from vald.v1.payload import payload_pb2 as vald_dot_v1_dot_payload_dot_payload__pb2


class FilterStub(object):
    """Represent the egress filter service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.FilterDistance = channel.unary_unary(
                '/filter.egress.v1.Filter/FilterDistance',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Distance.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Distance.FromString,
                )
        self.FilterVector = channel.unary_unary(
                '/filter.egress.v1.Filter/FilterVector',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Vector.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Vector.FromString,
                )


class FilterServicer(object):
    """Represent the egress filter service.
    """

    def FilterDistance(self, request, context):
        """Represent the RPC to filter the distance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FilterVector(self, request, context):
        """Represent the RPC to filter the vector.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FilterServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'FilterDistance': grpc.unary_unary_rpc_method_handler(
                    servicer.FilterDistance,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Distance.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Distance.SerializeToString,
            ),
            'FilterVector': grpc.unary_unary_rpc_method_handler(
                    servicer.FilterVector,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Vector.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Vector.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'filter.egress.v1.Filter', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Filter(object):
    """Represent the egress filter service.
    """

    @staticmethod
    def FilterDistance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/filter.egress.v1.Filter/FilterDistance',
            vald_dot_v1_dot_payload_dot_payload__pb2.Object.Distance.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Object.Distance.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FilterVector(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/filter.egress.v1.Filter/FilterVector',
            vald_dot_v1_dot_payload_dot_payload__pb2.Object.Vector.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Object.Vector.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from vald.v1.payload import payload_pb2 as vald_dot_v1_dot_payload_dot_payload__pb2


class AgentStub(object):
    """Represent the agent service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateIndex = channel.unary_unary(
                '/core.v1.Agent/CreateIndex',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Control.CreateIndexRequest.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Empty.FromString,
                )
        self.SaveIndex = channel.unary_unary(
                '/core.v1.Agent/SaveIndex',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Empty.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Empty.FromString,
                )
        self.CreateAndSaveIndex = channel.unary_unary(
                '/core.v1.Agent/CreateAndSaveIndex',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Control.CreateIndexRequest.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Empty.FromString,
                )
        self.IndexInfo = channel.unary_unary(
                '/core.v1.Agent/IndexInfo',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Empty.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Info.Index.Count.FromString,
                )


class AgentServicer(object):
    """Represent the agent service.
    """

    def CreateIndex(self, request, context):
        """Represent the create index RPC.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SaveIndex(self, request, context):
        """Represent the save index RPC.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAndSaveIndex(self, request, context):
        """Represent the create and save index RPC.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IndexInfo(self, request, context):
        """Represent the RPC to get the agent index information.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AgentServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateIndex': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateIndex,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Control.CreateIndexRequest.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Empty.SerializeToString,
            ),
            'SaveIndex': grpc.unary_unary_rpc_method_handler(
                    servicer.SaveIndex,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Empty.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Empty.SerializeToString,
            ),
            'CreateAndSaveIndex': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAndSaveIndex,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Control.CreateIndexRequest.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Empty.SerializeToString,
            ),
            'IndexInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.IndexInfo,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Empty.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Info.Index.Count.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'core.v1.Agent', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Agent(object):
    """Represent the agent service.
    """

    @staticmethod
    def CreateIndex(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.v1.Agent/CreateIndex',
            vald_dot_v1_dot_payload_dot_payload__pb2.Control.CreateIndexRequest.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SaveIndex(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.v1.Agent/SaveIndex',
            vald_dot_v1_dot_payload_dot_payload__pb2.Empty.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAndSaveIndex(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.v1.Agent/CreateAndSaveIndex',
            vald_dot_v1_dot_payload_dot_payload__pb2.Control.CreateIndexRequest.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IndexInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.v1.Agent/IndexInfo',
            vald_dot_v1_dot_payload_dot_payload__pb2.Empty.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Info.Index.Count.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vald/v1/vald/search.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vald.v1.payload import payload_pb2 as vald_dot_v1_dot_payload_dot_payload__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19vald/v1/vald/search.proto\x12\x07vald.v1\x1a\x1dvald/v1/payload/payload.proto\x1a\x1cgoogle/api/annotations.proto2\xd0\t\n\x06Search\x12U\n\x06Search\x12\x1a.payload.v1.Search.Request\x1a\x1b.payload.v1.Search.Response\"\x12\x82\xd3\xe4\x93\x02\x0c\"\x07/search:\x01*\x12^\n\nSearchByID\x12\x1c.payload.v1.Search.IDRequest\x1a\x1b.payload.v1.Search.Response\"\x15\x82\xd3\xe4\x93\x02\x0f\"\n/search/id:\x01*\x12S\n\x0cStreamSearch\x12\x1a.payload.v1.Search.Request\x1a!.payload.v1.Search.StreamResponse\"\x00(\x01\x30\x01\x12Y\n\x10StreamSearchByID\x12\x1c.payload.v1.Search.IDRequest\x1a!.payload.v1.Search.StreamResponse\"\x00(\x01\x30\x01\x12i\n\x0bMultiSearch\x12\x1f.payload.v1.Search.MultiRequest\x1a\x1c.payload.v1.Search.Responses\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/search/multiple:\x01*\x12r\n\x0fMultiSearchByID\x12!.payload.v1.Search.MultiIDRequest\x1a\x1c.payload.v1.Search.Responses\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/search/id/multiple:\x01*\x12\x61\n\x0cLinearSearch\x12\x1a.payload.v1.Search.Request\x1a\x1b.payload.v1.Search.Response\"\x18\x82\xd3\xe4\x93\x02\x12\"\r/linearsearch:\x01*\x12j\n\x10LinearSearchByID\x12\x1c.payload.v1.Search.IDRequest\x1a\x1b.payload.v1.Search.Response\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/linearsearch/id:\x01*\x12Y\n\x12StreamLinearSearch\x12\x1a.payload.v1.Search.Request\x1a!.payload.v1.Search.StreamResponse\"\x00(\x01\x30\x01\x12_\n\x16StreamLinearSearchByID\x12\x1c.payload.v1.Search.IDRequest\x1a!.payload.v1.Search.StreamResponse\"\x00(\x01\x30\x01\x12u\n\x11MultiLinearSearch\x12\x1f.payload.v1.Search.MultiRequest\x1a\x1c.payload.v1.Search.Responses\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/linearsearch/multiple:\x01*\x12~\n\x15MultiLinearSearchByID\x12!.payload.v1.Search.MultiIDRequest\x1a\x1c.payload.v1.Search.Responses\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/linearsearch/id/multiple:\x01*BS\n\x1aorg.vdaas.vald.api.v1.valdB\nValdSearchP\x01Z\'github.com/vdaas/vald/apis/grpc/v1/valdb\x06proto3')



_SEARCH = DESCRIPTOR.services_by_name['Search']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032org.vdaas.vald.api.v1.valdB\nValdSearchP\001Z\'github.com/vdaas/vald/apis/grpc/v1/vald'
  _SEARCH.methods_by_name['Search']._options = None
  _SEARCH.methods_by_name['Search']._serialized_options = b'\202\323\344\223\002\014\"\007/search:\001*'
  _SEARCH.methods_by_name['SearchByID']._options = None
  _SEARCH.methods_by_name['SearchByID']._serialized_options = b'\202\323\344\223\002\017\"\n/search/id:\001*'
  _SEARCH.methods_by_name['MultiSearch']._options = None
  _SEARCH.methods_by_name['MultiSearch']._serialized_options = b'\202\323\344\223\002\025\"\020/search/multiple:\001*'
  _SEARCH.methods_by_name['MultiSearchByID']._options = None
  _SEARCH.methods_by_name['MultiSearchByID']._serialized_options = b'\202\323\344\223\002\030\"\023/search/id/multiple:\001*'
  _SEARCH.methods_by_name['LinearSearch']._options = None
  _SEARCH.methods_by_name['LinearSearch']._serialized_options = b'\202\323\344\223\002\022\"\r/linearsearch:\001*'
  _SEARCH.methods_by_name['LinearSearchByID']._options = None
  _SEARCH.methods_by_name['LinearSearchByID']._serialized_options = b'\202\323\344\223\002\025\"\020/linearsearch/id:\001*'
  _SEARCH.methods_by_name['MultiLinearSearch']._options = None
  _SEARCH.methods_by_name['MultiLinearSearch']._serialized_options = b'\202\323\344\223\002\033\"\026/linearsearch/multiple:\001*'
  _SEARCH.methods_by_name['MultiLinearSearchByID']._options = None
  _SEARCH.methods_by_name['MultiLinearSearchByID']._serialized_options = b'\202\323\344\223\002\036\"\031/linearsearch/id/multiple:\001*'
  _SEARCH._serialized_start=100
  _SEARCH._serialized_end=1332
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vald/v1/vald/upsert.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vald.v1.payload import payload_pb2 as vald_dot_v1_dot_payload_dot_payload__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19vald/v1/vald/upsert.proto\x12\x07vald.v1\x1a\x1dvald/v1/payload/payload.proto\x1a\x1cgoogle/api/annotations.proto2\x9f\x02\n\x06Upsert\x12U\n\x06Upsert\x12\x1a.payload.v1.Upsert.Request\x1a\x1b.payload.v1.Object.Location\"\x12\x82\xd3\xe4\x93\x02\x0c\"\x07/upsert:\x01*\x12S\n\x0cStreamUpsert\x12\x1a.payload.v1.Upsert.Request\x1a!.payload.v1.Object.StreamLocation\"\x00(\x01\x30\x01\x12i\n\x0bMultiUpsert\x12\x1f.payload.v1.Upsert.MultiRequest\x1a\x1c.payload.v1.Object.Locations\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/upsert/multiple:\x01*BS\n\x1aorg.vdaas.vald.api.v1.valdB\nValdUpsertP\x01Z\'github.com/vdaas/vald/apis/grpc/v1/valdb\x06proto3')



_UPSERT = DESCRIPTOR.services_by_name['Upsert']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032org.vdaas.vald.api.v1.valdB\nValdUpsertP\001Z\'github.com/vdaas/vald/apis/grpc/v1/vald'
  _UPSERT.methods_by_name['Upsert']._options = None
  _UPSERT.methods_by_name['Upsert']._serialized_options = b'\202\323\344\223\002\014\"\007/upsert:\001*'
  _UPSERT.methods_by_name['MultiUpsert']._options = None
  _UPSERT.methods_by_name['MultiUpsert']._serialized_options = b'\202\323\344\223\002\025\"\020/upsert/multiple:\001*'
  _UPSERT._serialized_start=100
  _UPSERT._serialized_end=387
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from vald.v1.payload import payload_pb2 as vald_dot_v1_dot_payload_dot_payload__pb2


class FilterStub(object):
    """Filter service provides ways to connect to Vald through filter.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SearchObject = channel.unary_unary(
                '/vald.v1.Filter/SearchObject',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Search.ObjectRequest.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Search.Response.FromString,
                )
        self.MultiSearchObject = channel.unary_unary(
                '/vald.v1.Filter/MultiSearchObject',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Search.MultiObjectRequest.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Search.Responses.FromString,
                )
        self.StreamSearchObject = channel.stream_stream(
                '/vald.v1.Filter/StreamSearchObject',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Search.ObjectRequest.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Search.StreamResponse.FromString,
                )
        self.InsertObject = channel.unary_unary(
                '/vald.v1.Filter/InsertObject',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Insert.ObjectRequest.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Location.FromString,
                )
        self.StreamInsertObject = channel.stream_stream(
                '/vald.v1.Filter/StreamInsertObject',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Insert.ObjectRequest.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.StreamLocation.FromString,
                )
        self.MultiInsertObject = channel.unary_unary(
                '/vald.v1.Filter/MultiInsertObject',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Insert.MultiObjectRequest.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Locations.FromString,
                )
        self.UpdateObject = channel.unary_unary(
                '/vald.v1.Filter/UpdateObject',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Update.ObjectRequest.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Location.FromString,
                )
        self.StreamUpdateObject = channel.stream_stream(
                '/vald.v1.Filter/StreamUpdateObject',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Update.ObjectRequest.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.StreamLocation.FromString,
                )
        self.MultiUpdateObject = channel.unary_unary(
                '/vald.v1.Filter/MultiUpdateObject',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Update.MultiObjectRequest.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Locations.FromString,
                )
        self.UpsertObject = channel.unary_unary(
                '/vald.v1.Filter/UpsertObject',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Upsert.ObjectRequest.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Location.FromString,
                )
        self.StreamUpsertObject = channel.stream_stream(
                '/vald.v1.Filter/StreamUpsertObject',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Upsert.ObjectRequest.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.StreamLocation.FromString,
                )
        self.MultiUpsertObject = channel.unary_unary(
                '/vald.v1.Filter/MultiUpsertObject',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Upsert.MultiObjectRequest.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Locations.FromString,
                )


class FilterServicer(object):
    """Filter service provides ways to connect to Vald through filter.
    """

    def SearchObject(self, request, context):
        """A method to search object.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MultiSearchObject(self, request, context):
        """A method to search multiple objects.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamSearchObject(self, request_iterator, context):
        """A method to search object by bidirectional streaming.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InsertObject(self, request, context):
        """A method insert object.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamInsertObject(self, request_iterator, context):
        """Represent the streaming RPC to insert object by bidirectional streaming.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MultiInsertObject(self, request, context):
        """A method to insert multiple objects.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateObject(self, request, context):
        """A method to update object.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamUpdateObject(self, request_iterator, context):
        """A method to update object by bidirectional streaming.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MultiUpdateObject(self, request, context):
        """A method to update multiple objects.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpsertObject(self, request, context):
        """A method to upsert object.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamUpsertObject(self, request_iterator, context):
        """A method to upsert object by bidirectional streaming.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MultiUpsertObject(self, request, context):
        """A method to upsert multiple objects.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FilterServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SearchObject': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchObject,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Search.ObjectRequest.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Search.Response.SerializeToString,
            ),
            'MultiSearchObject': grpc.unary_unary_rpc_method_handler(
                    servicer.MultiSearchObject,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Search.MultiObjectRequest.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Search.Responses.SerializeToString,
            ),
            'StreamSearchObject': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamSearchObject,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Search.ObjectRequest.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Search.StreamResponse.SerializeToString,
            ),
            'InsertObject': grpc.unary_unary_rpc_method_handler(
                    servicer.InsertObject,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Insert.ObjectRequest.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Location.SerializeToString,
            ),
            'StreamInsertObject': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamInsertObject,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Insert.ObjectRequest.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.StreamLocation.SerializeToString,
            ),
            'MultiInsertObject': grpc.unary_unary_rpc_method_handler(
                    servicer.MultiInsertObject,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Insert.MultiObjectRequest.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Locations.SerializeToString,
            ),
            'UpdateObject': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateObject,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Update.ObjectRequest.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Location.SerializeToString,
            ),
            'StreamUpdateObject': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamUpdateObject,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Update.ObjectRequest.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.StreamLocation.SerializeToString,
            ),
            'MultiUpdateObject': grpc.unary_unary_rpc_method_handler(
                    servicer.MultiUpdateObject,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Update.MultiObjectRequest.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Locations.SerializeToString,
            ),
            'UpsertObject': grpc.unary_unary_rpc_method_handler(
                    servicer.UpsertObject,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Upsert.ObjectRequest.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Location.SerializeToString,
            ),
            'StreamUpsertObject': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamUpsertObject,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Upsert.ObjectRequest.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.StreamLocation.SerializeToString,
            ),
            'MultiUpsertObject': grpc.unary_unary_rpc_method_handler(
                    servicer.MultiUpsertObject,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Upsert.MultiObjectRequest.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Locations.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'vald.v1.Filter', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Filter(object):
    """Filter service provides ways to connect to Vald through filter.
    """

    @staticmethod
    def SearchObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.v1.Filter/SearchObject',
            vald_dot_v1_dot_payload_dot_payload__pb2.Search.ObjectRequest.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Search.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MultiSearchObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.v1.Filter/MultiSearchObject',
            vald_dot_v1_dot_payload_dot_payload__pb2.Search.MultiObjectRequest.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Search.Responses.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamSearchObject(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/vald.v1.Filter/StreamSearchObject',
            vald_dot_v1_dot_payload_dot_payload__pb2.Search.ObjectRequest.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Search.StreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InsertObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.v1.Filter/InsertObject',
            vald_dot_v1_dot_payload_dot_payload__pb2.Insert.ObjectRequest.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Object.Location.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamInsertObject(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/vald.v1.Filter/StreamInsertObject',
            vald_dot_v1_dot_payload_dot_payload__pb2.Insert.ObjectRequest.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Object.StreamLocation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MultiInsertObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.v1.Filter/MultiInsertObject',
            vald_dot_v1_dot_payload_dot_payload__pb2.Insert.MultiObjectRequest.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Object.Locations.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.v1.Filter/UpdateObject',
            vald_dot_v1_dot_payload_dot_payload__pb2.Update.ObjectRequest.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Object.Location.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamUpdateObject(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/vald.v1.Filter/StreamUpdateObject',
            vald_dot_v1_dot_payload_dot_payload__pb2.Update.ObjectRequest.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Object.StreamLocation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MultiUpdateObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.v1.Filter/MultiUpdateObject',
            vald_dot_v1_dot_payload_dot_payload__pb2.Update.MultiObjectRequest.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Object.Locations.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpsertObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.v1.Filter/UpsertObject',
            vald_dot_v1_dot_payload_dot_payload__pb2.Upsert.ObjectRequest.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Object.Location.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamUpsertObject(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/vald.v1.Filter/StreamUpsertObject',
            vald_dot_v1_dot_payload_dot_payload__pb2.Upsert.ObjectRequest.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Object.StreamLocation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MultiUpsertObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.v1.Filter/MultiUpsertObject',
            vald_dot_v1_dot_payload_dot_payload__pb2.Upsert.MultiObjectRequest.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Object.Locations.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vald/v1/filter/ingress/ingress_filter.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vald.v1.payload import payload_pb2 as vald_dot_v1_dot_payload_dot_payload__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+vald/v1/filter/ingress/ingress_filter.proto\x12\x11\x66ilter.ingress.v1\x1a\x1dvald/v1/payload/payload.proto\x1a\x1cgoogle/api/annotations.proto2\xd5\x01\n\x06\x46ilter\x12\x62\n\tGenVector\x12\x17.payload.v1.Object.Blob\x1a\x19.payload.v1.Object.Vector\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/filter/ingress/object:\x01*\x12g\n\x0c\x46ilterVector\x12\x19.payload.v1.Object.Vector\x1a\x19.payload.v1.Object.Vector\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/filter/ingress/vector:\x01*Bn\n$org.vdaas.vald.api.v1.filter.ingressB\x11ValdIngressFilterP\x01Z1github.com/vdaas/vald/apis/grpc/v1/filter/ingressb\x06proto3')



_FILTER = DESCRIPTOR.services_by_name['Filter']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$org.vdaas.vald.api.v1.filter.ingressB\021ValdIngressFilterP\001Z1github.com/vdaas/vald/apis/grpc/v1/filter/ingress'
  _FILTER.methods_by_name['GenVector']._options = None
  _FILTER.methods_by_name['GenVector']._serialized_options = b'\202\323\344\223\002\033\"\026/filter/ingress/object:\001*'
  _FILTER.methods_by_name['FilterVector']._options = None
  _FILTER.methods_by_name['FilterVector']._serialized_options = b'\202\323\344\223\002\033\"\026/filter/ingress/vector:\001*'
  _FILTER._serialized_start=128
  _FILTER._serialized_end=341
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from vald.v1.payload import payload_pb2 as vald_dot_v1_dot_payload_dot_payload__pb2


class UpdateStub(object):
    """Update service provides ways to update indexed vectors.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Update = channel.unary_unary(
                '/vald.v1.Update/Update',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Update.Request.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Location.FromString,
                )
        self.StreamUpdate = channel.stream_stream(
                '/vald.v1.Update/StreamUpdate',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Update.Request.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.StreamLocation.FromString,
                )
        self.MultiUpdate = channel.unary_unary(
                '/vald.v1.Update/MultiUpdate',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Update.MultiRequest.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Locations.FromString,
                )


class UpdateServicer(object):
    """Update service provides ways to update indexed vectors.
    """

    def Update(self, request, context):
        """A method to update an indexed vector.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamUpdate(self, request_iterator, context):
        """A method to update multiple indexed vectors by bidirectional streaming.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MultiUpdate(self, request, context):
        """A method to update multiple indexed vectors in a single request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UpdateServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Update.Request.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Location.SerializeToString,
            ),
            'StreamUpdate': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamUpdate,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Update.Request.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.StreamLocation.SerializeToString,
            ),
            'MultiUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.MultiUpdate,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Update.MultiRequest.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Locations.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'vald.v1.Update', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Update(object):
    """Update service provides ways to update indexed vectors.
    """

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.v1.Update/Update',
            vald_dot_v1_dot_payload_dot_payload__pb2.Update.Request.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Object.Location.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamUpdate(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/vald.v1.Update/StreamUpdate',
            vald_dot_v1_dot_payload_dot_payload__pb2.Update.Request.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Object.StreamLocation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MultiUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.v1.Update/MultiUpdate',
            vald_dot_v1_dot_payload_dot_payload__pb2.Update.MultiRequest.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Object.Locations.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vald/v1/agent/core/agent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vald.v1.payload import payload_pb2 as vald_dot_v1_dot_payload_dot_payload__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1evald/v1/agent/core/agent.proto\x12\x07\x63ore.v1\x1a\x1dvald/v1/payload/payload.proto\x1a\x1cgoogle/api/annotations.proto2\xf2\x02\n\x05\x41gent\x12_\n\x0b\x43reateIndex\x12&.payload.v1.Control.CreateIndexRequest\x1a\x11.payload.v1.Empty\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/index/create\x12\x46\n\tSaveIndex\x12\x11.payload.v1.Empty\x1a\x11.payload.v1.Empty\"\x13\x82\xd3\xe4\x93\x02\r\x12\x0b/index/save\x12m\n\x12\x43reateAndSaveIndex\x12&.payload.v1.Control.CreateIndexRequest\x1a\x11.payload.v1.Empty\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/index/createandsave\x12Q\n\tIndexInfo\x12\x11.payload.v1.Empty\x1a\x1c.payload.v1.Info.Index.Count\"\x13\x82\xd3\xe4\x93\x02\r\x12\x0b/index/infoB^\n org.vdaas.vald.api.v1.agent.coreB\tValdAgentP\x01Z-github.com/vdaas/vald/apis/grpc/v1/agent/coreb\x06proto3')



_AGENT = DESCRIPTOR.services_by_name['Agent']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n org.vdaas.vald.api.v1.agent.coreB\tValdAgentP\001Z-github.com/vdaas/vald/apis/grpc/v1/agent/core'
  _AGENT.methods_by_name['CreateIndex']._options = None
  _AGENT.methods_by_name['CreateIndex']._serialized_options = b'\202\323\344\223\002\017\022\r/index/create'
  _AGENT.methods_by_name['SaveIndex']._options = None
  _AGENT.methods_by_name['SaveIndex']._serialized_options = b'\202\323\344\223\002\r\022\013/index/save'
  _AGENT.methods_by_name['CreateAndSaveIndex']._options = None
  _AGENT.methods_by_name['CreateAndSaveIndex']._serialized_options = b'\202\323\344\223\002\026\022\024/index/createandsave'
  _AGENT.methods_by_name['IndexInfo']._options = None
  _AGENT.methods_by_name['IndexInfo']._serialized_options = b'\202\323\344\223\002\r\022\013/index/info'
  _AGENT._serialized_start=105
  _AGENT._serialized_end=475
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from vald.v1.payload import payload_pb2 as vald_dot_v1_dot_payload_dot_payload__pb2


class ObjectStub(object):
    """Object service provides ways to fetch indexed vectors.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Exists = channel.unary_unary(
                '/vald.v1.Object/Exists',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.ID.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.ID.FromString,
                )
        self.GetObject = channel.unary_unary(
                '/vald.v1.Object/GetObject',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.VectorRequest.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Vector.FromString,
                )
        self.StreamGetObject = channel.stream_stream(
                '/vald.v1.Object/StreamGetObject',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.VectorRequest.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.StreamVector.FromString,
                )


class ObjectServicer(object):
    """Object service provides ways to fetch indexed vectors.
    """

    def Exists(self, request, context):
        """A method to check whether a specified ID is indexed or not.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObject(self, request, context):
        """A method to fetch a vector.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamGetObject(self, request_iterator, context):
        """A method to fetch vectors by bidirectional streaming.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ObjectServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Exists': grpc.unary_unary_rpc_method_handler(
                    servicer.Exists,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.ID.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.ID.SerializeToString,
            ),
            'GetObject': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObject,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.VectorRequest.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Vector.SerializeToString,
            ),
            'StreamGetObject': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamGetObject,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.VectorRequest.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.StreamVector.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'vald.v1.Object', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Object(object):
    """Object service provides ways to fetch indexed vectors.
    """

    @staticmethod
    def Exists(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.v1.Object/Exists',
            vald_dot_v1_dot_payload_dot_payload__pb2.Object.ID.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Object.ID.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.v1.Object/GetObject',
            vald_dot_v1_dot_payload_dot_payload__pb2.Object.VectorRequest.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Object.Vector.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamGetObject(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/vald.v1.Object/StreamGetObject',
            vald_dot_v1_dot_payload_dot_payload__pb2.Object.VectorRequest.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Object.StreamVector.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from vald.v1.payload import payload_pb2 as vald_dot_v1_dot_payload_dot_payload__pb2


class UpsertStub(object):
    """Upsert service provides ways to insert/update vectors.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Upsert = channel.unary_unary(
                '/vald.v1.Upsert/Upsert',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Upsert.Request.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Location.FromString,
                )
        self.StreamUpsert = channel.stream_stream(
                '/vald.v1.Upsert/StreamUpsert',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Upsert.Request.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.StreamLocation.FromString,
                )
        self.MultiUpsert = channel.unary_unary(
                '/vald.v1.Upsert/MultiUpsert',
                request_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Upsert.MultiRequest.SerializeToString,
                response_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Locations.FromString,
                )


class UpsertServicer(object):
    """Upsert service provides ways to insert/update vectors.
    """

    def Upsert(self, request, context):
        """A method to insert/update a vector.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamUpsert(self, request_iterator, context):
        """A method to insert/update multiple vectors by bidirectional streaming.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MultiUpsert(self, request, context):
        """A method to insert/update multiple vectors in a single request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UpsertServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Upsert': grpc.unary_unary_rpc_method_handler(
                    servicer.Upsert,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Upsert.Request.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Location.SerializeToString,
            ),
            'StreamUpsert': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamUpsert,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Upsert.Request.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.StreamLocation.SerializeToString,
            ),
            'MultiUpsert': grpc.unary_unary_rpc_method_handler(
                    servicer.MultiUpsert,
                    request_deserializer=vald_dot_v1_dot_payload_dot_payload__pb2.Upsert.MultiRequest.FromString,
                    response_serializer=vald_dot_v1_dot_payload_dot_payload__pb2.Object.Locations.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'vald.v1.Upsert', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Upsert(object):
    """Upsert service provides ways to insert/update vectors.
    """

    @staticmethod
    def Upsert(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.v1.Upsert/Upsert',
            vald_dot_v1_dot_payload_dot_payload__pb2.Upsert.Request.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Object.Location.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamUpsert(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/vald.v1.Upsert/StreamUpsert',
            vald_dot_v1_dot_payload_dot_payload__pb2.Upsert.Request.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Object.StreamLocation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MultiUpsert(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.v1.Upsert/MultiUpsert',
            vald_dot_v1_dot_payload_dot_payload__pb2.Upsert.MultiRequest.SerializeToString,
            vald_dot_v1_dot_payload_dot_payload__pb2.Object.Locations.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vald/v1/vald/filter.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vald.v1.payload import payload_pb2 as vald_dot_v1_dot_payload_dot_payload__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19vald/v1/vald/filter.proto\x12\x07vald.v1\x1a\x1dvald/v1/payload/payload.proto\x1a\x1cgoogle/api/annotations.proto2\xac\n\n\x06\x46ilter\x12h\n\x0cSearchObject\x12 .payload.v1.Search.ObjectRequest\x1a\x1b.payload.v1.Search.Response\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/search/object:\x01*\x12|\n\x11MultiSearchObject\x12%.payload.v1.Search.MultiObjectRequest\x1a\x1c.payload.v1.Search.Responses\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/search/object/multiple:\x01*\x12_\n\x12StreamSearchObject\x12 .payload.v1.Search.ObjectRequest\x1a!.payload.v1.Search.StreamResponse\"\x00(\x01\x30\x01\x12h\n\x0cInsertObject\x12 .payload.v1.Insert.ObjectRequest\x1a\x1b.payload.v1.Object.Location\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/insert/object:\x01*\x12_\n\x12StreamInsertObject\x12 .payload.v1.Insert.ObjectRequest\x1a!.payload.v1.Object.StreamLocation\"\x00(\x01\x30\x01\x12|\n\x11MultiInsertObject\x12%.payload.v1.Insert.MultiObjectRequest\x1a\x1c.payload.v1.Object.Locations\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/insert/object/multiple:\x01*\x12h\n\x0cUpdateObject\x12 .payload.v1.Update.ObjectRequest\x1a\x1b.payload.v1.Object.Location\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/update/object:\x01*\x12_\n\x12StreamUpdateObject\x12 .payload.v1.Update.ObjectRequest\x1a!.payload.v1.Object.StreamLocation\"\x00(\x01\x30\x01\x12|\n\x11MultiUpdateObject\x12%.payload.v1.Update.MultiObjectRequest\x1a\x1c.payload.v1.Object.Locations\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/update/object/multiple:\x01*\x12h\n\x0cUpsertObject\x12 .payload.v1.Upsert.ObjectRequest\x1a\x1b.payload.v1.Object.Location\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/upsert/object:\x01*\x12_\n\x12StreamUpsertObject\x12 .payload.v1.Upsert.ObjectRequest\x1a!.payload.v1.Object.StreamLocation\"\x00(\x01\x30\x01\x12|\n\x11MultiUpsertObject\x12%.payload.v1.Upsert.MultiObjectRequest\x1a\x1c.payload.v1.Object.Locations\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/upsert/object/multiple:\x01*BS\n\x1aorg.vdaas.vald.api.v1.valdB\nValdFilterP\x01Z\'github.com/vdaas/vald/apis/grpc/v1/valdb\x06proto3')



_FILTER = DESCRIPTOR.services_by_name['Filter']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032org.vdaas.vald.api.v1.valdB\nValdFilterP\001Z\'github.com/vdaas/vald/apis/grpc/v1/vald'
  _FILTER.methods_by_name['SearchObject']._options = None
  _FILTER.methods_by_name['SearchObject']._serialized_options = b'\202\323\344\223\002\023\"\016/search/object:\001*'
  _FILTER.methods_by_name['MultiSearchObject']._options = None
  _FILTER.methods_by_name['MultiSearchObject']._serialized_options = b'\202\323\344\223\002\034\"\027/search/object/multiple:\001*'
  _FILTER.methods_by_name['InsertObject']._options = None
  _FILTER.methods_by_name['InsertObject']._serialized_options = b'\202\323\344\223\002\023\"\016/insert/object:\001*'
  _FILTER.methods_by_name['MultiInsertObject']._options = None
  _FILTER.methods_by_name['MultiInsertObject']._serialized_options = b'\202\323\344\223\002\034\"\027/insert/object/multiple:\001*'
  _FILTER.methods_by_name['UpdateObject']._options = None
  _FILTER.methods_by_name['UpdateObject']._serialized_options = b'\202\323\344\223\002\023\"\016/update/object:\001*'
  _FILTER.methods_by_name['MultiUpdateObject']._options = None
  _FILTER.methods_by_name['MultiUpdateObject']._serialized_options = b'\202\323\344\223\002\034\"\027/update/object/multiple:\001*'
  _FILTER.methods_by_name['UpsertObject']._options = None
  _FILTER.methods_by_name['UpsertObject']._serialized_options = b'\202\323\344\223\002\023\"\016/upsert/object:\001*'
  _FILTER.methods_by_name['MultiUpsertObject']._options = None
  _FILTER.methods_by_name['MultiUpsertObject']._serialized_options = b'\202\323\344\223\002\034\"\027/upsert/object/multiple:\001*'
  _FILTER._serialized_start=100
  _FILTER._serialized_end=1424
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vald/v1/payload/payload.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from validate import validate_pb2 as validate_dot_validate__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dvald/v1/payload/payload.proto\x12\npayload.v1\x1a\x17validate/validate.proto\x1a\x17google/rpc/status.proto\"\xc8\x07\n\x06Search\x1aN\n\x07Request\x12\x18\n\x06vector\x18\x01 \x03(\x02\x42\x08\xfa\x42\x05\x92\x01\x02\x08\x02\x12)\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x19.payload.v1.Search.Config\x1a<\n\x0cMultiRequest\x12,\n\x08requests\x18\x01 \x03(\x0b\x32\x1a.payload.v1.Search.Request\x1a\x42\n\tIDRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12)\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x19.payload.v1.Search.Config\x1a@\n\x0eMultiIDRequest\x12.\n\x08requests\x18\x01 \x03(\x0b\x32\x1c.payload.v1.Search.IDRequest\x1ay\n\rObjectRequest\x12\x0e\n\x06object\x18\x01 \x01(\x0c\x12)\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x19.payload.v1.Search.Config\x12-\n\nvectorizer\x18\x03 \x01(\x0b\x32\x19.payload.v1.Filter.Target\x1aH\n\x12MultiObjectRequest\x12\x32\n\x08requests\x18\x01 \x03(\x0b\x32 .payload.v1.Search.ObjectRequest\x1a\xe5\x01\n\x06\x43onfig\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x14\n\x03num\x18\x02 \x01(\rB\x07\xfa\x42\x04*\x02(\x01\x12\x0e\n\x06radius\x18\x03 \x01(\x02\x12\x0f\n\x07\x65psilon\x18\x04 \x01(\x02\x12\x0f\n\x07timeout\x18\x05 \x01(\x03\x12\x32\n\x0fingress_filters\x18\x06 \x01(\x0b\x32\x19.payload.v1.Filter.Config\x12\x31\n\x0e\x65gress_filters\x18\x07 \x01(\x0b\x32\x19.payload.v1.Filter.Config\x12\x18\n\x07min_num\x18\x08 \x01(\rB\x07\xfa\x42\x04*\x02(\x00\x1aL\n\x08Response\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12,\n\x07results\x18\x02 \x03(\x0b\x32\x1b.payload.v1.Object.Distance\x1a;\n\tResponses\x12.\n\tresponses\x18\x01 \x03(\x0b\x32\x1b.payload.v1.Search.Response\x1ar\n\x0eStreamResponse\x12/\n\x08response\x18\x01 \x01(\x0b\x32\x1b.payload.v1.Search.ResponseH\x00\x12$\n\x06status\x18\x02 \x01(\x0b\x32\x12.google.rpc.StatusH\x00\x42\t\n\x07payload\"d\n\x06\x46ilter\x1a$\n\x06Target\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\x1a\x34\n\x06\x43onfig\x12*\n\x07targets\x18\x01 \x03(\x0b\x32\x19.payload.v1.Filter.Target\"\xfa\x03\n\x06Insert\x1ai\n\x07Request\x12\x33\n\x06vector\x18\x01 \x01(\x0b\x32\x19.payload.v1.Object.VectorB\x08\xfa\x42\x05\x92\x01\x02\x08\x02\x12)\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x19.payload.v1.Insert.Config\x1a<\n\x0cMultiRequest\x12,\n\x08requests\x18\x01 \x03(\x0b\x32\x1a.payload.v1.Insert.Request\x1a\x92\x01\n\rObjectRequest\x12\'\n\x06object\x18\x01 \x01(\x0b\x32\x17.payload.v1.Object.Blob\x12)\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x19.payload.v1.Insert.Config\x12-\n\nvectorizer\x18\x03 \x01(\x0b\x32\x19.payload.v1.Filter.Target\x1aH\n\x12MultiObjectRequest\x12\x32\n\x08requests\x18\x01 \x03(\x0b\x32 .payload.v1.Insert.ObjectRequest\x1ah\n\x06\x43onfig\x12\x1f\n\x17skip_strict_exist_check\x18\x01 \x01(\x08\x12*\n\x07\x66ilters\x18\x02 \x01(\x0b\x32\x19.payload.v1.Filter.Config\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\"\xfa\x03\n\x06Update\x1ai\n\x07Request\x12\x33\n\x06vector\x18\x01 \x01(\x0b\x32\x19.payload.v1.Object.VectorB\x08\xfa\x42\x05\x92\x01\x02\x08\x02\x12)\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x19.payload.v1.Update.Config\x1a<\n\x0cMultiRequest\x12,\n\x08requests\x18\x01 \x03(\x0b\x32\x1a.payload.v1.Update.Request\x1a\x92\x01\n\rObjectRequest\x12\'\n\x06object\x18\x01 \x01(\x0b\x32\x17.payload.v1.Object.Blob\x12)\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x19.payload.v1.Update.Config\x12-\n\nvectorizer\x18\x03 \x01(\x0b\x32\x19.payload.v1.Filter.Target\x1aH\n\x12MultiObjectRequest\x12\x32\n\x08requests\x18\x01 \x03(\x0b\x32 .payload.v1.Update.ObjectRequest\x1ah\n\x06\x43onfig\x12\x1f\n\x17skip_strict_exist_check\x18\x01 \x01(\x08\x12*\n\x07\x66ilters\x18\x02 \x01(\x0b\x32\x19.payload.v1.Filter.Config\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\"\xfa\x03\n\x06Upsert\x1ai\n\x07Request\x12\x33\n\x06vector\x18\x01 \x01(\x0b\x32\x19.payload.v1.Object.VectorB\x08\xfa\x42\x05\x92\x01\x02\x08\x02\x12)\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x19.payload.v1.Upsert.Config\x1a<\n\x0cMultiRequest\x12,\n\x08requests\x18\x01 \x03(\x0b\x32\x1a.payload.v1.Upsert.Request\x1a\x92\x01\n\rObjectRequest\x12\'\n\x06object\x18\x01 \x01(\x0b\x32\x17.payload.v1.Object.Blob\x12)\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x19.payload.v1.Upsert.Config\x12-\n\nvectorizer\x18\x03 \x01(\x0b\x32\x19.payload.v1.Filter.Target\x1aH\n\x12MultiObjectRequest\x12\x32\n\x08requests\x18\x01 \x03(\x0b\x32 .payload.v1.Upsert.ObjectRequest\x1ah\n\x06\x43onfig\x12\x1f\n\x17skip_strict_exist_check\x18\x01 \x01(\x08\x12*\n\x07\x66ilters\x18\x02 \x01(\x0b\x32\x19.payload.v1.Filter.Config\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\"\xdd\x01\n\x06Remove\x1aW\n\x07Request\x12!\n\x02id\x18\x01 \x01(\x0b\x32\x15.payload.v1.Object.ID\x12)\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x19.payload.v1.Remove.Config\x1a<\n\x0cMultiRequest\x12,\n\x08requests\x18\x01 \x03(\x0b\x32\x1a.payload.v1.Remove.Request\x1a<\n\x06\x43onfig\x12\x1f\n\x17skip_strict_exist_check\x18\x01 \x01(\x08\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\"\xc8\x07\n\x06Object\x1ah\n\rVectorRequest\x12+\n\x02id\x18\x01 \x01(\x0b\x32\x15.payload.v1.Object.IDB\x08\xfa\x42\x05\x92\x01\x02\x08\x02\x12*\n\x07\x66ilters\x18\x02 \x01(\x0b\x32\x19.payload.v1.Filter.Config\x1a(\n\x08\x44istance\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x64istance\x18\x02 \x01(\x02\x1ar\n\x0eStreamDistance\x12/\n\x08\x64istance\x18\x01 \x01(\x0b\x32\x1b.payload.v1.Object.DistanceH\x00\x12$\n\x06status\x18\x02 \x01(\x0b\x32\x12.google.rpc.StatusH\x00\x42\t\n\x07payload\x1a\x19\n\x02ID\x12\x13\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1a\x12\n\x03IDs\x12\x0b\n\x03ids\x18\x01 \x03(\t\x1a\x37\n\x06Vector\x12\x13\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x06vector\x18\x02 \x03(\x02\x42\x08\xfa\x42\x05\x92\x01\x02\x08\x02\x1a\x35\n\x07Vectors\x12*\n\x07vectors\x18\x01 \x03(\x0b\x32\x19.payload.v1.Object.Vector\x1al\n\x0cStreamVector\x12+\n\x06vector\x18\x01 \x01(\x0b\x32\x19.payload.v1.Object.VectorH\x00\x12$\n\x06status\x18\x02 \x01(\x0b\x32\x12.google.rpc.StatusH\x00\x42\t\n\x07payload\x1a.\n\rReshapeVector\x12\x0e\n\x06object\x18\x01 \x01(\x0c\x12\r\n\x05shape\x18\x02 \x03(\x05\x1a+\n\x04\x42lob\x12\x13\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0e\n\x06object\x18\x02 \x01(\x0c\x1a\x66\n\nStreamBlob\x12\'\n\x04\x62lob\x18\x01 \x01(\x0b\x32\x17.payload.v1.Object.BlobH\x00\x12$\n\x06status\x18\x02 \x01(\x0b\x32\x12.google.rpc.StatusH\x00\x42\t\n\x07payload\x1a\x33\n\x08Location\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12\x0b\n\x03ips\x18\x03 \x03(\t\x1ar\n\x0eStreamLocation\x12/\n\x08location\x18\x01 \x01(\x0b\x32\x1b.payload.v1.Object.LocationH\x00\x12$\n\x06status\x18\x02 \x01(\x0b\x32\x12.google.rpc.StatusH\x00\x42\t\n\x07payload\x1a;\n\tLocations\x12.\n\tlocations\x18\x01 \x03(\x0b\x32\x1b.payload.v1.Object.Location\";\n\x07\x43ontrol\x1a\x30\n\x12\x43reateIndexRequest\x12\x1a\n\tpool_size\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02(\x00\"O\n\nDiscoverer\x1a\x41\n\x07Request\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x0c\n\x04node\x18\x03 \x01(\t\"\x88\x06\n\x04Info\x1a\x97\x01\n\x05Index\x1aN\n\x05\x43ount\x12\x0e\n\x06stored\x18\x01 \x01(\r\x12\x13\n\x0buncommitted\x18\x02 \x01(\r\x12\x10\n\x08indexing\x18\x03 \x01(\x08\x12\x0e\n\x06saving\x18\x04 \x01(\x08\x1a>\n\x04UUID\x1a\x19\n\tCommitted\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x1a\x1b\n\x0bUncommitted\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x1a\xbe\x01\n\x03Pod\x12\x10\n\x08\x61pp_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x13\n\x02ip\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02x\x01\x12!\n\x03\x63pu\x18\x05 \x01(\x0b\x32\x14.payload.v1.Info.CPU\x12\'\n\x06memory\x18\x06 \x01(\x0b\x32\x17.payload.v1.Info.Memory\x12#\n\x04node\x18\x07 \x01(\x0b\x32\x15.payload.v1.Info.Node\x1a\xb3\x01\n\x04Node\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rinternal_addr\x18\x02 \x01(\t\x12\x15\n\rexternal_addr\x18\x03 \x01(\t\x12!\n\x03\x63pu\x18\x04 \x01(\x0b\x32\x14.payload.v1.Info.CPU\x12\'\n\x06memory\x18\x05 \x01(\x0b\x32\x17.payload.v1.Info.Memory\x12#\n\x04Pods\x18\x06 \x01(\x0b\x32\x15.payload.v1.Info.Pods\x1a\x34\n\x03\x43PU\x12\r\n\x05limit\x18\x01 \x01(\x01\x12\x0f\n\x07request\x18\x02 \x01(\x01\x12\r\n\x05usage\x18\x03 \x01(\x01\x1a\x37\n\x06Memory\x12\r\n\x05limit\x18\x01 \x01(\x01\x12\x0f\n\x07request\x18\x02 \x01(\x01\x12\r\n\x05usage\x18\x03 \x01(\x01\x1a\x34\n\x04Pods\x12,\n\x04pods\x18\x01 \x03(\x0b\x32\x14.payload.v1.Info.PodB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\x37\n\x05Nodes\x12.\n\x05nodes\x18\x01 \x03(\x0b\x32\x15.payload.v1.Info.NodeB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\x11\n\x03IPs\x12\n\n\x02ip\x18\x01 \x03(\t\"\x07\n\x05\x45mptyBZ\n\x1dorg.vdaas.vald.api.v1.payloadB\x0bValdPayloadP\x01Z*github.com/vdaas/vald/apis/grpc/v1/payloadb\x06proto3')



_SEARCH = DESCRIPTOR.message_types_by_name['Search']
_SEARCH_REQUEST = _SEARCH.nested_types_by_name['Request']
_SEARCH_MULTIREQUEST = _SEARCH.nested_types_by_name['MultiRequest']
_SEARCH_IDREQUEST = _SEARCH.nested_types_by_name['IDRequest']
_SEARCH_MULTIIDREQUEST = _SEARCH.nested_types_by_name['MultiIDRequest']
_SEARCH_OBJECTREQUEST = _SEARCH.nested_types_by_name['ObjectRequest']
_SEARCH_MULTIOBJECTREQUEST = _SEARCH.nested_types_by_name['MultiObjectRequest']
_SEARCH_CONFIG = _SEARCH.nested_types_by_name['Config']
_SEARCH_RESPONSE = _SEARCH.nested_types_by_name['Response']
_SEARCH_RESPONSES = _SEARCH.nested_types_by_name['Responses']
_SEARCH_STREAMRESPONSE = _SEARCH.nested_types_by_name['StreamResponse']
_FILTER = DESCRIPTOR.message_types_by_name['Filter']
_FILTER_TARGET = _FILTER.nested_types_by_name['Target']
_FILTER_CONFIG = _FILTER.nested_types_by_name['Config']
_INSERT = DESCRIPTOR.message_types_by_name['Insert']
_INSERT_REQUEST = _INSERT.nested_types_by_name['Request']
_INSERT_MULTIREQUEST = _INSERT.nested_types_by_name['MultiRequest']
_INSERT_OBJECTREQUEST = _INSERT.nested_types_by_name['ObjectRequest']
_INSERT_MULTIOBJECTREQUEST = _INSERT.nested_types_by_name['MultiObjectRequest']
_INSERT_CONFIG = _INSERT.nested_types_by_name['Config']
_UPDATE = DESCRIPTOR.message_types_by_name['Update']
_UPDATE_REQUEST = _UPDATE.nested_types_by_name['Request']
_UPDATE_MULTIREQUEST = _UPDATE.nested_types_by_name['MultiRequest']
_UPDATE_OBJECTREQUEST = _UPDATE.nested_types_by_name['ObjectRequest']
_UPDATE_MULTIOBJECTREQUEST = _UPDATE.nested_types_by_name['MultiObjectRequest']
_UPDATE_CONFIG = _UPDATE.nested_types_by_name['Config']
_UPSERT = DESCRIPTOR.message_types_by_name['Upsert']
_UPSERT_REQUEST = _UPSERT.nested_types_by_name['Request']
_UPSERT_MULTIREQUEST = _UPSERT.nested_types_by_name['MultiRequest']
_UPSERT_OBJECTREQUEST = _UPSERT.nested_types_by_name['ObjectRequest']
_UPSERT_MULTIOBJECTREQUEST = _UPSERT.nested_types_by_name['MultiObjectRequest']
_UPSERT_CONFIG = _UPSERT.nested_types_by_name['Config']
_REMOVE = DESCRIPTOR.message_types_by_name['Remove']
_REMOVE_REQUEST = _REMOVE.nested_types_by_name['Request']
_REMOVE_MULTIREQUEST = _REMOVE.nested_types_by_name['MultiRequest']
_REMOVE_CONFIG = _REMOVE.nested_types_by_name['Config']
_OBJECT = DESCRIPTOR.message_types_by_name['Object']
_OBJECT_VECTORREQUEST = _OBJECT.nested_types_by_name['VectorRequest']
_OBJECT_DISTANCE = _OBJECT.nested_types_by_name['Distance']
_OBJECT_STREAMDISTANCE = _OBJECT.nested_types_by_name['StreamDistance']
_OBJECT_ID = _OBJECT.nested_types_by_name['ID']
_OBJECT_IDS = _OBJECT.nested_types_by_name['IDs']
_OBJECT_VECTOR = _OBJECT.nested_types_by_name['Vector']
_OBJECT_VECTORS = _OBJECT.nested_types_by_name['Vectors']
_OBJECT_STREAMVECTOR = _OBJECT.nested_types_by_name['StreamVector']
_OBJECT_RESHAPEVECTOR = _OBJECT.nested_types_by_name['ReshapeVector']
_OBJECT_BLOB = _OBJECT.nested_types_by_name['Blob']
_OBJECT_STREAMBLOB = _OBJECT.nested_types_by_name['StreamBlob']
_OBJECT_LOCATION = _OBJECT.nested_types_by_name['Location']
_OBJECT_STREAMLOCATION = _OBJECT.nested_types_by_name['StreamLocation']
_OBJECT_LOCATIONS = _OBJECT.nested_types_by_name['Locations']
_CONTROL = DESCRIPTOR.message_types_by_name['Control']
_CONTROL_CREATEINDEXREQUEST = _CONTROL.nested_types_by_name['CreateIndexRequest']
_DISCOVERER = DESCRIPTOR.message_types_by_name['Discoverer']
_DISCOVERER_REQUEST = _DISCOVERER.nested_types_by_name['Request']
_INFO = DESCRIPTOR.message_types_by_name['Info']
_INFO_INDEX = _INFO.nested_types_by_name['Index']
_INFO_INDEX_COUNT = _INFO_INDEX.nested_types_by_name['Count']
_INFO_INDEX_UUID = _INFO_INDEX.nested_types_by_name['UUID']
_INFO_INDEX_UUID_COMMITTED = _INFO_INDEX_UUID.nested_types_by_name['Committed']
_INFO_INDEX_UUID_UNCOMMITTED = _INFO_INDEX_UUID.nested_types_by_name['Uncommitted']
_INFO_POD = _INFO.nested_types_by_name['Pod']
_INFO_NODE = _INFO.nested_types_by_name['Node']
_INFO_CPU = _INFO.nested_types_by_name['CPU']
_INFO_MEMORY = _INFO.nested_types_by_name['Memory']
_INFO_PODS = _INFO.nested_types_by_name['Pods']
_INFO_NODES = _INFO.nested_types_by_name['Nodes']
_INFO_IPS = _INFO.nested_types_by_name['IPs']
_EMPTY = DESCRIPTOR.message_types_by_name['Empty']
Search = _reflection.GeneratedProtocolMessageType('Search', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
    'DESCRIPTOR' : _SEARCH_REQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Search.Request)
    })
  ,

  'MultiRequest' : _reflection.GeneratedProtocolMessageType('MultiRequest', (_message.Message,), {
    'DESCRIPTOR' : _SEARCH_MULTIREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Search.MultiRequest)
    })
  ,

  'IDRequest' : _reflection.GeneratedProtocolMessageType('IDRequest', (_message.Message,), {
    'DESCRIPTOR' : _SEARCH_IDREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Search.IDRequest)
    })
  ,

  'MultiIDRequest' : _reflection.GeneratedProtocolMessageType('MultiIDRequest', (_message.Message,), {
    'DESCRIPTOR' : _SEARCH_MULTIIDREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Search.MultiIDRequest)
    })
  ,

  'ObjectRequest' : _reflection.GeneratedProtocolMessageType('ObjectRequest', (_message.Message,), {
    'DESCRIPTOR' : _SEARCH_OBJECTREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Search.ObjectRequest)
    })
  ,

  'MultiObjectRequest' : _reflection.GeneratedProtocolMessageType('MultiObjectRequest', (_message.Message,), {
    'DESCRIPTOR' : _SEARCH_MULTIOBJECTREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Search.MultiObjectRequest)
    })
  ,

  'Config' : _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
    'DESCRIPTOR' : _SEARCH_CONFIG,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Search.Config)
    })
  ,

  'Response' : _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
    'DESCRIPTOR' : _SEARCH_RESPONSE,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Search.Response)
    })
  ,

  'Responses' : _reflection.GeneratedProtocolMessageType('Responses', (_message.Message,), {
    'DESCRIPTOR' : _SEARCH_RESPONSES,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Search.Responses)
    })
  ,

  'StreamResponse' : _reflection.GeneratedProtocolMessageType('StreamResponse', (_message.Message,), {
    'DESCRIPTOR' : _SEARCH_STREAMRESPONSE,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Search.StreamResponse)
    })
  ,
  'DESCRIPTOR' : _SEARCH,
  '__module__' : 'vald.v1.payload.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.v1.Search)
  })
_sym_db.RegisterMessage(Search)
_sym_db.RegisterMessage(Search.Request)
_sym_db.RegisterMessage(Search.MultiRequest)
_sym_db.RegisterMessage(Search.IDRequest)
_sym_db.RegisterMessage(Search.MultiIDRequest)
_sym_db.RegisterMessage(Search.ObjectRequest)
_sym_db.RegisterMessage(Search.MultiObjectRequest)
_sym_db.RegisterMessage(Search.Config)
_sym_db.RegisterMessage(Search.Response)
_sym_db.RegisterMessage(Search.Responses)
_sym_db.RegisterMessage(Search.StreamResponse)

Filter = _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {

  'Target' : _reflection.GeneratedProtocolMessageType('Target', (_message.Message,), {
    'DESCRIPTOR' : _FILTER_TARGET,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Filter.Target)
    })
  ,

  'Config' : _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
    'DESCRIPTOR' : _FILTER_CONFIG,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Filter.Config)
    })
  ,
  'DESCRIPTOR' : _FILTER,
  '__module__' : 'vald.v1.payload.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.v1.Filter)
  })
_sym_db.RegisterMessage(Filter)
_sym_db.RegisterMessage(Filter.Target)
_sym_db.RegisterMessage(Filter.Config)

Insert = _reflection.GeneratedProtocolMessageType('Insert', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
    'DESCRIPTOR' : _INSERT_REQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Insert.Request)
    })
  ,

  'MultiRequest' : _reflection.GeneratedProtocolMessageType('MultiRequest', (_message.Message,), {
    'DESCRIPTOR' : _INSERT_MULTIREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Insert.MultiRequest)
    })
  ,

  'ObjectRequest' : _reflection.GeneratedProtocolMessageType('ObjectRequest', (_message.Message,), {
    'DESCRIPTOR' : _INSERT_OBJECTREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Insert.ObjectRequest)
    })
  ,

  'MultiObjectRequest' : _reflection.GeneratedProtocolMessageType('MultiObjectRequest', (_message.Message,), {
    'DESCRIPTOR' : _INSERT_MULTIOBJECTREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Insert.MultiObjectRequest)
    })
  ,

  'Config' : _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
    'DESCRIPTOR' : _INSERT_CONFIG,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Insert.Config)
    })
  ,
  'DESCRIPTOR' : _INSERT,
  '__module__' : 'vald.v1.payload.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.v1.Insert)
  })
_sym_db.RegisterMessage(Insert)
_sym_db.RegisterMessage(Insert.Request)
_sym_db.RegisterMessage(Insert.MultiRequest)
_sym_db.RegisterMessage(Insert.ObjectRequest)
_sym_db.RegisterMessage(Insert.MultiObjectRequest)
_sym_db.RegisterMessage(Insert.Config)

Update = _reflection.GeneratedProtocolMessageType('Update', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
    'DESCRIPTOR' : _UPDATE_REQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Update.Request)
    })
  ,

  'MultiRequest' : _reflection.GeneratedProtocolMessageType('MultiRequest', (_message.Message,), {
    'DESCRIPTOR' : _UPDATE_MULTIREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Update.MultiRequest)
    })
  ,

  'ObjectRequest' : _reflection.GeneratedProtocolMessageType('ObjectRequest', (_message.Message,), {
    'DESCRIPTOR' : _UPDATE_OBJECTREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Update.ObjectRequest)
    })
  ,

  'MultiObjectRequest' : _reflection.GeneratedProtocolMessageType('MultiObjectRequest', (_message.Message,), {
    'DESCRIPTOR' : _UPDATE_MULTIOBJECTREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Update.MultiObjectRequest)
    })
  ,

  'Config' : _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
    'DESCRIPTOR' : _UPDATE_CONFIG,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Update.Config)
    })
  ,
  'DESCRIPTOR' : _UPDATE,
  '__module__' : 'vald.v1.payload.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.v1.Update)
  })
_sym_db.RegisterMessage(Update)
_sym_db.RegisterMessage(Update.Request)
_sym_db.RegisterMessage(Update.MultiRequest)
_sym_db.RegisterMessage(Update.ObjectRequest)
_sym_db.RegisterMessage(Update.MultiObjectRequest)
_sym_db.RegisterMessage(Update.Config)

Upsert = _reflection.GeneratedProtocolMessageType('Upsert', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
    'DESCRIPTOR' : _UPSERT_REQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Upsert.Request)
    })
  ,

  'MultiRequest' : _reflection.GeneratedProtocolMessageType('MultiRequest', (_message.Message,), {
    'DESCRIPTOR' : _UPSERT_MULTIREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Upsert.MultiRequest)
    })
  ,

  'ObjectRequest' : _reflection.GeneratedProtocolMessageType('ObjectRequest', (_message.Message,), {
    'DESCRIPTOR' : _UPSERT_OBJECTREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Upsert.ObjectRequest)
    })
  ,

  'MultiObjectRequest' : _reflection.GeneratedProtocolMessageType('MultiObjectRequest', (_message.Message,), {
    'DESCRIPTOR' : _UPSERT_MULTIOBJECTREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Upsert.MultiObjectRequest)
    })
  ,

  'Config' : _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
    'DESCRIPTOR' : _UPSERT_CONFIG,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Upsert.Config)
    })
  ,
  'DESCRIPTOR' : _UPSERT,
  '__module__' : 'vald.v1.payload.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.v1.Upsert)
  })
_sym_db.RegisterMessage(Upsert)
_sym_db.RegisterMessage(Upsert.Request)
_sym_db.RegisterMessage(Upsert.MultiRequest)
_sym_db.RegisterMessage(Upsert.ObjectRequest)
_sym_db.RegisterMessage(Upsert.MultiObjectRequest)
_sym_db.RegisterMessage(Upsert.Config)

Remove = _reflection.GeneratedProtocolMessageType('Remove', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
    'DESCRIPTOR' : _REMOVE_REQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Remove.Request)
    })
  ,

  'MultiRequest' : _reflection.GeneratedProtocolMessageType('MultiRequest', (_message.Message,), {
    'DESCRIPTOR' : _REMOVE_MULTIREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Remove.MultiRequest)
    })
  ,

  'Config' : _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
    'DESCRIPTOR' : _REMOVE_CONFIG,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Remove.Config)
    })
  ,
  'DESCRIPTOR' : _REMOVE,
  '__module__' : 'vald.v1.payload.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.v1.Remove)
  })
_sym_db.RegisterMessage(Remove)
_sym_db.RegisterMessage(Remove.Request)
_sym_db.RegisterMessage(Remove.MultiRequest)
_sym_db.RegisterMessage(Remove.Config)

Object = _reflection.GeneratedProtocolMessageType('Object', (_message.Message,), {

  'VectorRequest' : _reflection.GeneratedProtocolMessageType('VectorRequest', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_VECTORREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.VectorRequest)
    })
  ,

  'Distance' : _reflection.GeneratedProtocolMessageType('Distance', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_DISTANCE,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.Distance)
    })
  ,

  'StreamDistance' : _reflection.GeneratedProtocolMessageType('StreamDistance', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_STREAMDISTANCE,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.StreamDistance)
    })
  ,

  'ID' : _reflection.GeneratedProtocolMessageType('ID', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_ID,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.ID)
    })
  ,

  'IDs' : _reflection.GeneratedProtocolMessageType('IDs', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_IDS,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.IDs)
    })
  ,

  'Vector' : _reflection.GeneratedProtocolMessageType('Vector', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_VECTOR,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.Vector)
    })
  ,

  'Vectors' : _reflection.GeneratedProtocolMessageType('Vectors', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_VECTORS,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.Vectors)
    })
  ,

  'StreamVector' : _reflection.GeneratedProtocolMessageType('StreamVector', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_STREAMVECTOR,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.StreamVector)
    })
  ,

  'ReshapeVector' : _reflection.GeneratedProtocolMessageType('ReshapeVector', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_RESHAPEVECTOR,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.ReshapeVector)
    })
  ,

  'Blob' : _reflection.GeneratedProtocolMessageType('Blob', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_BLOB,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.Blob)
    })
  ,

  'StreamBlob' : _reflection.GeneratedProtocolMessageType('StreamBlob', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_STREAMBLOB,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.StreamBlob)
    })
  ,

  'Location' : _reflection.GeneratedProtocolMessageType('Location', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_LOCATION,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.Location)
    })
  ,

  'StreamLocation' : _reflection.GeneratedProtocolMessageType('StreamLocation', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_STREAMLOCATION,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.StreamLocation)
    })
  ,

  'Locations' : _reflection.GeneratedProtocolMessageType('Locations', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_LOCATIONS,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.Locations)
    })
  ,
  'DESCRIPTOR' : _OBJECT,
  '__module__' : 'vald.v1.payload.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.v1.Object)
  })
_sym_db.RegisterMessage(Object)
_sym_db.RegisterMessage(Object.VectorRequest)
_sym_db.RegisterMessage(Object.Distance)
_sym_db.RegisterMessage(Object.StreamDistance)
_sym_db.RegisterMessage(Object.ID)
_sym_db.RegisterMessage(Object.IDs)
_sym_db.RegisterMessage(Object.Vector)
_sym_db.RegisterMessage(Object.Vectors)
_sym_db.RegisterMessage(Object.StreamVector)
_sym_db.RegisterMessage(Object.ReshapeVector)
_sym_db.RegisterMessage(Object.Blob)
_sym_db.RegisterMessage(Object.StreamBlob)
_sym_db.RegisterMessage(Object.Location)
_sym_db.RegisterMessage(Object.StreamLocation)
_sym_db.RegisterMessage(Object.Locations)

Control = _reflection.GeneratedProtocolMessageType('Control', (_message.Message,), {

  'CreateIndexRequest' : _reflection.GeneratedProtocolMessageType('CreateIndexRequest', (_message.Message,), {
    'DESCRIPTOR' : _CONTROL_CREATEINDEXREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Control.CreateIndexRequest)
    })
  ,
  'DESCRIPTOR' : _CONTROL,
  '__module__' : 'vald.v1.payload.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.v1.Control)
  })
_sym_db.RegisterMessage(Control)
_sym_db.RegisterMessage(Control.CreateIndexRequest)

Discoverer = _reflection.GeneratedProtocolMessageType('Discoverer', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
    'DESCRIPTOR' : _DISCOVERER_REQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Discoverer.Request)
    })
  ,
  'DESCRIPTOR' : _DISCOVERER,
  '__module__' : 'vald.v1.payload.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.v1.Discoverer)
  })
_sym_db.RegisterMessage(Discoverer)
_sym_db.RegisterMessage(Discoverer.Request)

Info = _reflection.GeneratedProtocolMessageType('Info', (_message.Message,), {

  'Index' : _reflection.GeneratedProtocolMessageType('Index', (_message.Message,), {

    'Count' : _reflection.GeneratedProtocolMessageType('Count', (_message.Message,), {
      'DESCRIPTOR' : _INFO_INDEX_COUNT,
      '__module__' : 'vald.v1.payload.payload_pb2'
      # @@protoc_insertion_point(class_scope:payload.v1.Info.Index.Count)
      })
    ,

    'UUID' : _reflection.GeneratedProtocolMessageType('UUID', (_message.Message,), {

      'Committed' : _reflection.GeneratedProtocolMessageType('Committed', (_message.Message,), {
        'DESCRIPTOR' : _INFO_INDEX_UUID_COMMITTED,
        '__module__' : 'vald.v1.payload.payload_pb2'
        # @@protoc_insertion_point(class_scope:payload.v1.Info.Index.UUID.Committed)
        })
      ,

      'Uncommitted' : _reflection.GeneratedProtocolMessageType('Uncommitted', (_message.Message,), {
        'DESCRIPTOR' : _INFO_INDEX_UUID_UNCOMMITTED,
        '__module__' : 'vald.v1.payload.payload_pb2'
        # @@protoc_insertion_point(class_scope:payload.v1.Info.Index.UUID.Uncommitted)
        })
      ,
      'DESCRIPTOR' : _INFO_INDEX_UUID,
      '__module__' : 'vald.v1.payload.payload_pb2'
      # @@protoc_insertion_point(class_scope:payload.v1.Info.Index.UUID)
      })
    ,
    'DESCRIPTOR' : _INFO_INDEX,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Info.Index)
    })
  ,

  'Pod' : _reflection.GeneratedProtocolMessageType('Pod', (_message.Message,), {
    'DESCRIPTOR' : _INFO_POD,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Info.Pod)
    })
  ,

  'Node' : _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), {
    'DESCRIPTOR' : _INFO_NODE,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Info.Node)
    })
  ,

  'CPU' : _reflection.GeneratedProtocolMessageType('CPU', (_message.Message,), {
    'DESCRIPTOR' : _INFO_CPU,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Info.CPU)
    })
  ,

  'Memory' : _reflection.GeneratedProtocolMessageType('Memory', (_message.Message,), {
    'DESCRIPTOR' : _INFO_MEMORY,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Info.Memory)
    })
  ,

  'Pods' : _reflection.GeneratedProtocolMessageType('Pods', (_message.Message,), {
    'DESCRIPTOR' : _INFO_PODS,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Info.Pods)
    })
  ,

  'Nodes' : _reflection.GeneratedProtocolMessageType('Nodes', (_message.Message,), {
    'DESCRIPTOR' : _INFO_NODES,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Info.Nodes)
    })
  ,

  'IPs' : _reflection.GeneratedProtocolMessageType('IPs', (_message.Message,), {
    'DESCRIPTOR' : _INFO_IPS,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Info.IPs)
    })
  ,
  'DESCRIPTOR' : _INFO,
  '__module__' : 'vald.v1.payload.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.v1.Info)
  })
_sym_db.RegisterMessage(Info)
_sym_db.RegisterMessage(Info.Index)
_sym_db.RegisterMessage(Info.Index.Count)
_sym_db.RegisterMessage(Info.Index.UUID)
_sym_db.RegisterMessage(Info.Index.UUID.Committed)
_sym_db.RegisterMessage(Info.Index.UUID.Uncommitted)
_sym_db.RegisterMessage(Info.Pod)
_sym_db.RegisterMessage(Info.Node)
_sym_db.RegisterMessage(Info.CPU)
_sym_db.RegisterMessage(Info.Memory)
_sym_db.RegisterMessage(Info.Pods)
_sym_db.RegisterMessage(Info.Nodes)
_sym_db.RegisterMessage(Info.IPs)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
  'DESCRIPTOR' : _EMPTY,
  '__module__' : 'vald.v1.payload.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.v1.Empty)
  })
_sym_db.RegisterMessage(Empty)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035org.vdaas.vald.api.v1.payloadB\013ValdPayloadP\001Z*github.com/vdaas/vald/apis/grpc/v1/payload'
  _SEARCH_REQUEST.fields_by_name['vector']._options = None
  _SEARCH_REQUEST.fields_by_name['vector']._serialized_options = b'\372B\005\222\001\002\010\002'
  _SEARCH_CONFIG.fields_by_name['num']._options = None
  _SEARCH_CONFIG.fields_by_name['num']._serialized_options = b'\372B\004*\002(\001'
  _SEARCH_CONFIG.fields_by_name['min_num']._options = None
  _SEARCH_CONFIG.fields_by_name['min_num']._serialized_options = b'\372B\004*\002(\000'
  _INSERT_REQUEST.fields_by_name['vector']._options = None
  _INSERT_REQUEST.fields_by_name['vector']._serialized_options = b'\372B\005\222\001\002\010\002'
  _UPDATE_REQUEST.fields_by_name['vector']._options = None
  _UPDATE_REQUEST.fields_by_name['vector']._serialized_options = b'\372B\005\222\001\002\010\002'
  _UPSERT_REQUEST.fields_by_name['vector']._options = None
  _UPSERT_REQUEST.fields_by_name['vector']._serialized_options = b'\372B\005\222\001\002\010\002'
  _OBJECT_VECTORREQUEST.fields_by_name['id']._options = None
  _OBJECT_VECTORREQUEST.fields_by_name['id']._serialized_options = b'\372B\005\222\001\002\010\002'
  _OBJECT_ID.fields_by_name['id']._options = None
  _OBJECT_ID.fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _OBJECT_VECTOR.fields_by_name['id']._options = None
  _OBJECT_VECTOR.fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _OBJECT_VECTOR.fields_by_name['vector']._options = None
  _OBJECT_VECTOR.fields_by_name['vector']._serialized_options = b'\372B\005\222\001\002\010\002'
  _OBJECT_BLOB.fields_by_name['id']._options = None
  _OBJECT_BLOB.fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _CONTROL_CREATEINDEXREQUEST.fields_by_name['pool_size']._options = None
  _CONTROL_CREATEINDEXREQUEST.fields_by_name['pool_size']._serialized_options = b'\372B\004*\002(\000'
  _DISCOVERER_REQUEST.fields_by_name['name']._options = None
  _DISCOVERER_REQUEST.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _INFO_POD.fields_by_name['ip']._options = None
  _INFO_POD.fields_by_name['ip']._serialized_options = b'\372B\004r\002x\001'
  _INFO_PODS.fields_by_name['pods']._options = None
  _INFO_PODS.fields_by_name['pods']._serialized_options = b'\372B\005\222\001\002\010\001'
  _INFO_NODES.fields_by_name['nodes']._options = None
  _INFO_NODES.fields_by_name['nodes']._serialized_options = b'\372B\005\222\001\002\010\001'
  _SEARCH._serialized_start=96
  _SEARCH._serialized_end=1064
  _SEARCH_REQUEST._serialized_start=106
  _SEARCH_REQUEST._serialized_end=184
  _SEARCH_MULTIREQUEST._serialized_start=186
  _SEARCH_MULTIREQUEST._serialized_end=246
  _SEARCH_IDREQUEST._serialized_start=248
  _SEARCH_IDREQUEST._serialized_end=314
  _SEARCH_MULTIIDREQUEST._serialized_start=316
  _SEARCH_MULTIIDREQUEST._serialized_end=380
  _SEARCH_OBJECTREQUEST._serialized_start=382
  _SEARCH_OBJECTREQUEST._serialized_end=503
  _SEARCH_MULTIOBJECTREQUEST._serialized_start=505
  _SEARCH_MULTIOBJECTREQUEST._serialized_end=577
  _SEARCH_CONFIG._serialized_start=580
  _SEARCH_CONFIG._serialized_end=809
  _SEARCH_RESPONSE._serialized_start=811
  _SEARCH_RESPONSE._serialized_end=887
  _SEARCH_RESPONSES._serialized_start=889
  _SEARCH_RESPONSES._serialized_end=948
  _SEARCH_STREAMRESPONSE._serialized_start=950
  _SEARCH_STREAMRESPONSE._serialized_end=1064
  _FILTER._serialized_start=1066
  _FILTER._serialized_end=1166
  _FILTER_TARGET._serialized_start=1076
  _FILTER_TARGET._serialized_end=1112
  _FILTER_CONFIG._serialized_start=1114
  _FILTER_CONFIG._serialized_end=1166
  _INSERT._serialized_start=1169
  _INSERT._serialized_end=1675
  _INSERT_REQUEST._serialized_start=1179
  _INSERT_REQUEST._serialized_end=1284
  _INSERT_MULTIREQUEST._serialized_start=1286
  _INSERT_MULTIREQUEST._serialized_end=1346
  _INSERT_OBJECTREQUEST._serialized_start=1349
  _INSERT_OBJECTREQUEST._serialized_end=1495
  _INSERT_MULTIOBJECTREQUEST._serialized_start=1497
  _INSERT_MULTIOBJECTREQUEST._serialized_end=1569
  _INSERT_CONFIG._serialized_start=1571
  _INSERT_CONFIG._serialized_end=1675
  _UPDATE._serialized_start=1678
  _UPDATE._serialized_end=2184
  _UPDATE_REQUEST._serialized_start=1688
  _UPDATE_REQUEST._serialized_end=1793
  _UPDATE_MULTIREQUEST._serialized_start=1795
  _UPDATE_MULTIREQUEST._serialized_end=1855
  _UPDATE_OBJECTREQUEST._serialized_start=1858
  _UPDATE_OBJECTREQUEST._serialized_end=2004
  _UPDATE_MULTIOBJECTREQUEST._serialized_start=2006
  _UPDATE_MULTIOBJECTREQUEST._serialized_end=2078
  _UPDATE_CONFIG._serialized_start=1571
  _UPDATE_CONFIG._serialized_end=1675
  _UPSERT._serialized_start=2187
  _UPSERT._serialized_end=2693
  _UPSERT_REQUEST._serialized_start=2197
  _UPSERT_REQUEST._serialized_end=2302
  _UPSERT_MULTIREQUEST._serialized_start=2304
  _UPSERT_MULTIREQUEST._serialized_end=2364
  _UPSERT_OBJECTREQUEST._serialized_start=2367
  _UPSERT_OBJECTREQUEST._serialized_end=2513
  _UPSERT_MULTIOBJECTREQUEST._serialized_start=2515
  _UPSERT_MULTIOBJECTREQUEST._serialized_end=2587
  _UPSERT_CONFIG._serialized_start=1571
  _UPSERT_CONFIG._serialized_end=1675
  _REMOVE._serialized_start=2696
  _REMOVE._serialized_end=2917
  _REMOVE_REQUEST._serialized_start=2706
  _REMOVE_REQUEST._serialized_end=2793
  _REMOVE_MULTIREQUEST._serialized_start=2795
  _REMOVE_MULTIREQUEST._serialized_end=2855
  _REMOVE_CONFIG._serialized_start=2857
  _REMOVE_CONFIG._serialized_end=2917
  _OBJECT._serialized_start=2920
  _OBJECT._serialized_end=3888
  _OBJECT_VECTORREQUEST._serialized_start=2930
  _OBJECT_VECTORREQUEST._serialized_end=3034
  _OBJECT_DISTANCE._serialized_start=3036
  _OBJECT_DISTANCE._serialized_end=3076
  _OBJECT_STREAMDISTANCE._serialized_start=3078
  _OBJECT_STREAMDISTANCE._serialized_end=3192
  _OBJECT_ID._serialized_start=3194
  _OBJECT_ID._serialized_end=3219
  _OBJECT_IDS._serialized_start=3221
  _OBJECT_IDS._serialized_end=3239
  _OBJECT_VECTOR._serialized_start=3241
  _OBJECT_VECTOR._serialized_end=3296
  _OBJECT_VECTORS._serialized_start=3298
  _OBJECT_VECTORS._serialized_end=3351
  _OBJECT_STREAMVECTOR._serialized_start=3353
  _OBJECT_STREAMVECTOR._serialized_end=3461
  _OBJECT_RESHAPEVECTOR._serialized_start=3463
  _OBJECT_RESHAPEVECTOR._serialized_end=3509
  _OBJECT_BLOB._serialized_start=3511
  _OBJECT_BLOB._serialized_end=3554
  _OBJECT_STREAMBLOB._serialized_start=3556
  _OBJECT_STREAMBLOB._serialized_end=3658
  _OBJECT_LOCATION._serialized_start=3660
  _OBJECT_LOCATION._serialized_end=3711
  _OBJECT_STREAMLOCATION._serialized_start=3713
  _OBJECT_STREAMLOCATION._serialized_end=3827
  _OBJECT_LOCATIONS._serialized_start=3829
  _OBJECT_LOCATIONS._serialized_end=3888
  _CONTROL._serialized_start=3890
  _CONTROL._serialized_end=3949
  _CONTROL_CREATEINDEXREQUEST._serialized_start=3901
  _CONTROL_CREATEINDEXREQUEST._serialized_end=3949
  _DISCOVERER._serialized_start=3951
  _DISCOVERER._serialized_end=4030
  _DISCOVERER_REQUEST._serialized_start=3965
  _DISCOVERER_REQUEST._serialized_end=4030
  _INFO._serialized_start=4033
  _INFO._serialized_end=4809
  _INFO_INDEX._serialized_start=4042
  _INFO_INDEX._serialized_end=4193
  _INFO_INDEX_COUNT._serialized_start=4051
  _INFO_INDEX_COUNT._serialized_end=4129
  _INFO_INDEX_UUID._serialized_start=4131
  _INFO_INDEX_UUID._serialized_end=4193
  _INFO_INDEX_UUID_COMMITTED._serialized_start=4139
  _INFO_INDEX_UUID_COMMITTED._serialized_end=4164
  _INFO_INDEX_UUID_UNCOMMITTED._serialized_start=4166
  _INFO_INDEX_UUID_UNCOMMITTED._serialized_end=4193
  _INFO_POD._serialized_start=4196
  _INFO_POD._serialized_end=4386
  _INFO_NODE._serialized_start=4389
  _INFO_NODE._serialized_end=4568
  _INFO_CPU._serialized_start=4570
  _INFO_CPU._serialized_end=4622
  _INFO_MEMORY._serialized_start=4624
  _INFO_MEMORY._serialized_end=4679
  _INFO_PODS._serialized_start=4681
  _INFO_PODS._serialized_end=4733
  _INFO_NODES._serialized_start=4735
  _INFO_NODES._serialized_end=4790
  _INFO_IPS._serialized_start=4792
  _INFO_IPS._serialized_end=4809
  _EMPTY._serialized_start=4811
  _EMPTY._serialized_end=4818
# @@protoc_insertion_point(module_scope)
